from django.apps import AppConfig


class TaskAppConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'task_app'

    def ready(self):
        from .utils import startup
        startup(0)

