# Generated by Django 4.0.2 on 2022-02-26 19:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('task_app', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='taskqueue',
            name='date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
