# Generated by Django 4.0.2 on 2022-02-26 18:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='change_status_on',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
