# Generated by Django 4.0.2 on 2022-02-26 18:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('blog', '0002_article_change_status_on'),
    ]

    operations = [
        migrations.CreateModel(
            name='TaskQueue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_on', models.DateTimeField(auto_now_add=True)),
                ('updated_on', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('waiting', 'Waiting'), ('completed', 'Completed')], default='waiting', max_length=10)),
                ('date_time', models.DateTimeField()),
                ('article', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='blog.article')),
            ],
            options={
                'verbose_name': 'Task',
                'verbose_name_plural': 'TaskQueue',
                'ordering': ['date_time', 'id'],
            },
        ),
    ]
